#
# spec file for package skelcd-control-openSUSE
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change the control file or this spec file
#   in build service directly, use
#   https://github.com/yast/skelcd-control-openSUSE repository
#
#   See https://github.com/yast/skelcd-control-openSUSE/blob/master/CONTRIBUTING.md
#   for more details.
#
######################################################################
Name:           skelcd-control-openSUSE
Version:        20190312
Release:        1.1
Summary:        The openSUSE Installation Control file
License:        MIT
Group:          Metapackages
Url:            https://github.com/yast/skelcd-control-openSUSE
Source:         skelcd-control-openSUSE-%{version}.tar.bz2
# we do not distribute it, but need to have it here, otherwise build service checks complain
Source99:       README.md
# xmllint
BuildRequires:  libxml2-tools
# xsltproc
BuildRequires:  libxslt-tools
# RNG schema
BuildRequires:  yast2-installation-control >= 4.0.10
######################################################################
#
# Here is the list of Yast packages which are needed in the
# installation system (inst-sys) for the Yast installer
#
# Generic Yast packages needed for the installer
#
######################################################################
Requires:       autoyast2
Requires:       yast2-add-on
Requires:       yast2-fcoe-client
# For creating the AutoYast profile at the end of installation (bnc#887406)
Requires:       yast2-firewall
# instsys_cleanup
Requires:       yast2-installation >= 3.1.201
Requires:       yast2-iscsi-client
Requires:       yast2-kdump
Requires:       yast2-multipath
Requires:       yast2-network >= 3.1.24
Requires:       yast2-nfs-client
Requires:       yast2-ntp-client
Requires:       yast2-proxy
# this is the default theme
Requires:       yast2-configuration-management
Requires:       yast2-qt-branding-openSUSE
Requires:       yast2-services-manager
Requires:       yast2-slp
Requires:       yast2-theme
Requires:       yast2-trans-stats
Requires:       yast2-tune
Requires:       yast2-update
Requires:       yast2-users
Requires:       yast2-x11
# Ruby debugger in the inst-sys (FATE#318421)
Requires:       rubygem(%{rb_default_ruby_abi}:byebug)

Conflicts:      product_control
Provides:       product_control
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Architecture specific packages
%ifarch s390 s390x
Requires:       yast2-reipl >= 3.1.4
Requires:       yast2-s390
%endif

%ifarch %ix86 x86_64
Requires:       yast2-vm
%endif

%if 0%{?suse_version} >= 1500 && !0%{?skelcd_compat}
%define skelcdpath /usr/lib/skelcd
%endif

%description
This package contains the control file used for openSUSE installation.

%prep

%setup -q -n skelcd-control-openSUSE-%{version}

%build
make %{?_smp_mflags} -C control

%check
make %{?_smp_mflags} -C control check

%install
#
# Add control file
#
%if "%{name}" == "skelcd-control-openSUSE-promo"
    CONTROL_FILE=control.openSUSE-promo.xml
%else
    CONTROL_FILE=control.openSUSE.xml
%endif

mkdir -p $RPM_BUILD_ROOT%{?skelcdpath}/CD1
install -m 644 control/${CONTROL_FILE} $RPM_BUILD_ROOT%{?skelcdpath}/CD1/control.xml

%ifarch aarch64 %arm ppc ppc64 ppc64le
    %ifarch ppc ppc64 ppc64le
        ports_arch="ppc"
    %else
        ports_arch="%{_arch}"
    %endif
    sed -i -e "s,http://download.opensuse.org/distribution/,http://download.opensuse.org/ports/$ports_arch/distribution/," %{buildroot}%{?skelcdpath}/CD1/control.xml
    sed -i -e "s,http://download.opensuse.org/tumbleweed/,http://download.opensuse.org/ports/$ports_arch/tumbleweed/," %{buildroot}%{?skelcdpath}/CD1/control.xml
    sed -i -e "s,http://download.opensuse.org/debug/,http://download.opensuse.org/ports/$ports_arch/debug/," %{buildroot}%{?skelcdpath}/CD1/control.xml
    sed -i -e "s,http://download.opensuse.org/source/,http://download.opensuse.org/ports/$ports_arch/source/," %{buildroot}%{?skelcdpath}/CD1/control.xml
    sed -i -e "s,http://download.opensuse.org/update/tumbleweed/,http://download.opensuse.org/ports/$ports_arch/update/tumbleweed/," %{buildroot}%{?skelcdpath}/CD1/control.xml
    #we parse out non existing non-oss repo for ports
    xsltproc -o %{buildroot}%{?skelcdpath}/CD1/control_ports.xml control/nonoss.xsl %{buildroot}%{?skelcdpath}/CD1/control.xml
    mv %{buildroot}%{?skelcdpath}/CD1/control{_ports,}.xml
    xmllint --noout --relaxng %{_datadir}/YaST2/control/control.rng %{buildroot}%{?skelcdpath}/CD1/control.xml
%endif

%files
%defattr(644,root,root,755)
%if %{defined skelcdpath}
%dir %{skelcdpath}
%endif
%dir %{?skelcdpath}/CD1
%{?skelcdpath}/CD1/control.xml

%changelog
* Tue Mar 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Change product_license_dir to /usr/share/licenses/product/base
  after discussion, FATE#324053
* Tue Mar 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Changed product_license_dir define from /etc/YaST2/licenses/base/
  to /usr/share/licenses/product/, see jsc#SLE-3067
* Mon Feb 25 2019 dgonzalez@suse.com
- Add network to the installation proposal (fate#326480).
- 20190225
* Wed Feb 13 2019 jsegitz@suse.com
- Enable firewall by default in server install profiles (boo#1090372)
- 20190213
* Fri Dec  7 2018 Richard Brown <rbrown@suse.com>
- Adjust / partition size to fit with 20GB aspirational minimum
  * btrfs root will be at least 17.5GB, leaving 2.5 GB swap & EFI
  * boo#1093372
- 20181207
* Wed Dec  5 2018 Richard Brown <rbrown@suse.com>
- Allow snapshot disabling if not enough disk space (boo#1093372)
- 20181205
* Mon Dec  3 2018 Richard Brown <rbrown@suse.com>
- Remove fallback_for_XXX parameters for /home (boo#1093372)
- 20181203
* Thu Nov 29 2018 Stasiek Michalski <hellcp@mailbox.org>
- Update yast2-theme dependency (boo#1108422)
- 20181129
* Thu Nov 22 2018 Richard Brown <rbrown@suse.com>
- Improve default partition sizes (boo#1093372)
- Enable sshd and disable firewall by default on server roles
  (boo#1090372)
- 20181122
* Wed Nov 21 2018 dgonzalez@suse.com
- Remove not needed step names from the sidebar (bsc#1115986)
- 20181121
* Wed Nov 14 2018 Stefan Hundhammer <shundhammer@suse.com>
- Added workflow step to add online repos during installation
  (bsc#1112937)
- 20181114
* Sat Nov 10 2018 hellcp@opensuse.org
- Switch installation UI for openSUSE to sidebar (boo#1088785)
- 20181113
* Fri Aug 31 2018 lnussel@suse.de
- Change text in role selection
- Remove no longer used desktop_dialog tag
- Introduce "Generic Desktop" role
- 42.3.99.32
* Thu Aug 30 2018 lslezak@suse.cz
- Mark the upgrade from openSUSE Leap 15.x as supported
  (bsc#1105335)
- 42.3.99.31
* Thu Jul 19 2018 rbrown@suse.com
- Remove 'Custom' system_role due to incompatibily with SLE-15 role
  screen (bsc#1100417)
- 42.3.99.30
* Fri Jul  6 2018 rbrown@suse.com
- NetworkManager as default for desktop system roles
- Wicked for default for server roles
- Use of SLE-15 system role screen
- Tidy up of old desktop selection options that are no longer
  needed (bsc#1100417)
- 42.3.99.29
* Tue Jun 12 2018 rbrown@suse.com
- Add missing aarch64 grub2 efi subvolume (bsc#1097235)
- 42.3.99.28
* Mon May 14 2018 igonzalezsosa@suse.com
- Add yast2-configuration-management to the installation media
  (bsc#1093078).
- 42.3.99.27
* Wed Apr 11 2018 rbrown@suse.com
- Rename readonly_root_tools to transactional_base (boo#1089095)
- 42.3.99.26
* Tue Apr 10 2018 rbrown@suse.com
- Rename Transactional Server role (boo#1088893)
- Set Server role to use enhanced_base (boo#1088884)
- 42.3.99.25
* Thu Mar 29 2018 rbrown@suse.com
- Unify serverro role partition config with Kubic (boo#1087449)
- 42.3.99.24
* Fri Mar 16 2018 rbrown@suse.com
- Introduce "Server with Transactional Updates and Read-Only Root
  Filesystem" System Role (bsc#1084149)
- Create /root subvolume on fresh installs (bsc#1085266)
- Re-order installation workflow to ensure partitioning is
  configured after the system role has altered it
- Download release notes earlier in installation workflow
- 42.3.99.23
* Thu Mar 15 2018 knut.anderssen@suse.com
- Unification of firewall proposals (fate#323460, bsc#1085125)
- 42.3.99.22
* Tue Mar 13 2018 igonzalezsosa@suse.com
- Replace root_subvolume_read_only with btrfs_read_only (related
  to bsc#1079000).
- 42.3.99.21
* Thu Mar  8 2018 knut.anderssen@suse.com
- Added the fcoe-client to the list of clonable modules
  (bsc#1078991).
- 42.3.99.20
* Mon Jan 22 2018 normand@linux.vnet.ibm.com
- in spec file change xsltproc parms to avoid PowerPC build error
  supposed to solve error since commit#c5e2b30 bsc#1049297
- 42.3.99.19
* Wed Jan 17 2018 snwint@suse.de
- rewrite partitioning section to use new storage-ng setting
- 42.3.99.18
* Tue Dec 12 2017 rbrown@suse.com
- adjust subvolume list to have NoCOW /var instead of many
  subvolumes (boo#1075369)
- 42.3.99.17
* Fri Dec  1 2017 dimstar@opensuse.org
- In case prjconf defines skelcd_compat, do not yet move skelcdpath
  to /usr/lib. This allows TW to move suse_version ahead of
  SLE15, without being forced to switch to the new product builder
  (boo#1071232).
- 42.3.99.16
* Fri Oct  6 2017 lnussel@suse.de
- use /usr/lib/skelcd conditionally
- 42.3.99.15
* Thu Sep 21 2017 jreidinger@suse.com
- Adapt to changes in roles (needed for fixing bsc#1049297)
- 42.3.99.14
* Wed Sep  6 2017 igonzalezsosa@suse.com
- Initialize libzypp in advance in order to read the product's
  license (fate#322276)
- 42.3.99.13
* Wed Aug 30 2017 gsouza@suse.com
- Added complex welcome module to autoinstallation in order to
  display README.BETA in case it exists. (bsc#1047060)
- 42.3.99.12
* Thu Aug 17 2017 lslezak@suse.cz
- Use HTTPS protocol for downloading the community repositories
  (bsc#1054198)
- 42.3.99.11
* Thu Aug  3 2017 jreidinger@suse.com
- place skelcd to /usr/lib/skelcd (bsc#1031335)
- 42.3.99.10
* Wed Jun 28 2017 lnussel@suse.de
- Reword role selection dialog (boo#1045180)
- 42.3.99.9
* Tue Jun 20 2017 cwh@suse.com
- added yast2-s390 as a requirement for s390(x) as a Storage NG
  requirement (fate#318196)
- 42.3.99.8
* Wed Jun  7 2017 mfilka@suse.com
- bnc#1042482
  - Fixed "Server role" description
- 42.3.99.7
* Thu Jun  1 2017 schubi@suse.de
- The "custom" role displays manual the pattern selection dialog
  in the installation workflow. The default pre-selected patterns
  can be configured in the "control.xml" file in the "system_role"
  section.(bnc#1031295)
- 42.3.99.6
* Wed May 17 2017 lslezak@suse.cz
- Added the new TW identification to the list of the products
  supported for upgrade (bsc#1039193)
- 42.3.99.5
* Tue May  9 2017 sflees@suse.de
- Replace the generic_server pattern reference with console.
  * As part of the patterns cleanup the generic_server pattern
    was merged into the console pattern and removed. (bsc#1038233)
- 42.3.99.4
* Tue Apr 18 2017 tchvatal@suse.com
- In desktop selector keep all choices unselected for user to decide
  (poo#14936, bsc#1025415)
- 42.3.99.3
* Wed Feb  8 2017 jreidinger@suse.com
- add new desktop selection workflow (poo#14936, bsc#1025415)
- 42.3.2
* Wed Jan 25 2017 jreidinger@suse.com
- initial support for s390 (bsc#1021615)
* Thu Jan  5 2017 dmueller@suse.com
- Fix Leap 42.3 setup for ports ( lets reuse previous bnc#1010989)
- 42.3.1
* Tue Dec  6 2016 jberry@suse.com
- Start Leap 42.3 version.
- 42.3.0
* Tue Nov 22 2016 schubi@suse.de
- control.xml: Removed double entries "branding-openSUSE" from
  supported_desktops/one_supported_desktop/packages.
  (bnc#1010989)
- 42.2.99.4
* Wed Nov  2 2016 shundhammer@suse.de
- Added subvolumes (fate#321737)
- 42.2.99.3
* Wed Oct 12 2016 mfilka@suse.com
- Removed reference to netprobe client. It was used in AutoYaST
  only and everything what this client does should be currently
  handled by wicked.
- 42.2.99.2
* Thu Sep  8 2016 lslezak@suse.cz
- Cleanup: remove the LiveCD configuration, the yast2-live-installer
  package was dropped in Tumbleweed (bsc#997829)
- 42.2.99.1
* Fri Aug 26 2016 igonzalezsosa@suse.com
-  Move the YaST self update step earlier in the workflow to avoid
  bugs caused by restarting YaST (boo#995771)
- 42.2.4
* Thu Aug 25 2016 dimstar@opensuse.org
- Drop the 'Minimal Server Selection' which is basically the same
  as "Server (Text Mode)" already (boo#962725).
- 42.2.3
* Mon Aug  8 2016 dimstar@opensuse.org
- Use icewm as DEFAULT_WM when installing MinimalX. This in fact
  only configures what had been defacto the case for like ever:
  as twm is not part of the x11 pattern there was simply a fallback
  to icewm happening (boo#993309).
- 42.2.2
* Thu Jul 28 2016 dimstar@opensuse.org
- Use lightdm instead of lxdm as displaymanager when installing
  LXDE as primary desktop.
- 42.2.1
* Thu Jul 21 2016 lslezak@suse.cz
- Remove some files from the inst-sys to have more free RAM on low
  memory systems (bsc#974601)
- 42.2.0
* Tue Jun 14 2016 igonzalezsosa@suse.com
- Delay self-update during autoupgrade until software manager
  is initialized (bsc#984656)
- 13.2.31
* Wed May 25 2016 schubi@suse.de
- Cloning ssh_import settings for AutoYaST (FATE#319624).
- 13.2.30
* Thu May 19 2016 lslezak@suse.cz
- Include the Ruby debugger (byebug) in the inst-sys for easier
  YaST debugging (FATE#318421)
- 13.2.29
* Mon May 16 2016 ancor@suse.com
- Removed not longer necessary items from copy_to_system section
- Added SSH keys import section to the proposal
- Fate#319624
- 13.2.28
* Thu Apr 14 2016 lnussel@suse.de
- Remove vm_keep_unpartitioned_region
- 13.2.27
* Wed Apr  6 2016 igonzalezsosa@suse.com
- Automatically update the installer in the initial stage of:
  installation, update, autoinstallation and autoupgrade.
  Not affected: live_installation. (FATE#319716).
- 13.2.26
* Mon Dec 21 2015 ancor@suse.com
- Added ed25519 keys to import_ssh_keys (boo#956515)
- 13.2.25
* Fri Oct 16 2015 dmueller@suse.com
- add emergency update channel for the tumbleweed ports
- 13.2.24
* Tue Sep 29 2015 jreidinger@suse.com
- The e17 pattern was renamed to enlightenment a while back, adapt
  the Display manager dialog to this change
  by Simon Lees <simon@simotek.net>
- 13.2.23
* Wed Sep 23 2015 sndirsch@suse.com
- use empty string as DISPLAYMANAGER for minimal+X11 and textmode
  pattern, which on the system already results in chosing xdm as
  default DM; this enables us to set displaymanager in %%post of
  the appropriated DM package (FATE#319432)
* Thu Apr 30 2015 mlin@suse.com
- Use Plasma 5 as default KDE environment
- 13.2.22
* Wed Mar 18 2015 dvaleev@suse.com
- Parse out non-oss repos for Power as we don't build those repos
  for PowerPC
- 13.2.21
* Thu Mar  5 2015 dvaleev@suse.com
- Change repositories for Tumbleweed for PowerPC as well
- Change repos on ppc64le as well
- 13.2.20
* Mon Jan 19 2015 dimstar@opensuse.org
- Change repositories for Tumbleweed from /factory to /tumbleweed
  (boo#913561).
- 13.2.19
* Wed Jan 14 2015 coolo@suse.com
- allow upgrades from TW snapshots
- 13.2.18
* Mon Jan  5 2015 jreidinger@suse.com
- allow smooth upgrade to grub2 during upgrade
  (bnc#900824, bnc#906124)
- 13.2.17
* Tue Oct  7 2014 coolo@suse.com
- for Factory we only have one update repository not 4
- 13.2.16
* Mon Sep 15 2014 coolo@suse.com
- remove clients from 2nd stage that no longer exist. For now we keep
  the 2nd stage
- 13.2.15
* Mon Aug  4 2014 locilka@suse.com
- Added yast2-firewall to inst-sys dependencies - required for
  creating the AutoYast profile at the end of installation
  (bnc#887406)
- 13.2.14
* Mon Jun 23 2014 jreidinger@suse.com
- remove non-existing client from autoupgrade work-flow
- 13.2.13
* Tue Jun 17 2014 coolo@suse.com
- Replace 13.2 repos with Factory repos till 13.2 is forked
- 13.2.12
* Wed May 28 2014 locilka@suse.com
- Added handling for upgrading default desktops using
  software->upgrade->window_managers (bnc#874116)
- 13.2.11
* Thu May 22 2014 jreidinger@suse.com
- UPGRADE: remove client to convert bootloader configuration from
  lilo(bnc#878833)
- UPGRADE: drop ancient /dev/hd* to /dev/sd* conversion client
- 13.2.10
* Fri May  9 2014 jsrain@suse.cz
- download release notes for add-ons (bnc#876700)
- 13.2.9
* Mon Mar 31 2014 jreidinger@suse.com
- have complete autoyast2 in inst-sys otherwise cloning in first
  stage won't work (bnc#869175)
- 13.2.8
* Thu Feb 27 2014 mfilka@suse.com
- added reference to linuxrc network configuration client
- 13.2.7
* Fri Jan 31 2014 lslezak@suse.cz
- fixed package dependencies
- 13.2.6
* Tue Jan 28 2014 lslezak@suse.cz
- add Yast dependencies to include the installer packages into
  inst-sys
- 13.2.5
* Mon Jan 27 2014 locilka@suse.com
- Installation Media removed from upgrade proposal (bnc#857681)
- Fixed a typo while preparing images (needed for FATE#308539)
- version 13.2.4
* Tue Jan 21 2014 jreidinger@suse.com
- Remove "use images" from summary page and do it automatic as it
  now works enough realiable and provide no real user benefit to
  change proposal
- version 13.2.3
* Mon Jan 13 2014 jreidinger@suse.com
- add clone client that handle autoyast cloning settings
  (FATE#308539)
- version 13.2.2
* Thu Jan  9 2014 lslezak@suse.cz
- the package is maintained now at Yast GitHub repository
  (https://github.com/yast/skelcd-control-openSUSE)
- changed versioning schema to 13.2.x (distribution release
  prefix), magic get_version_number.sh script has been removed
- version 13.2.1
* Fri Dec 20 2013 coolo@suse.com
- control files moved to yast2-installation-control now
* Tue Dec 10 2013 lslezak@suse.cz
- updated control.xml (removed second stage) to validate against
  the latest control.rng
- use http://download.opensuse.org/ports/ppc/ instead of
  http://powerpc.opensuse.org in online repositories (PPC only)
* Tue Oct 29 2013 fcrozat@suse.com
- Add id to copy_to_system_item node in control.xml (fix build).
- Regenerate promo patch to fix fuzziness.
* Wed Oct  2 2013 lnussel@suse.de
- don't install original control.xml twice
* Fri Sep 27 2013 coolo@suse.com
- add a warning for updating old openSUSE versions
- add a special control.xml for promo dvd to warn about all updates
* Fri Sep 27 2013 jsuchome@suse.cz
- yast2-mouse dropped
* Mon Sep  2 2013 jsuchome@suse.cz
- do not install xorg-x11 (bnc#837450)
* Mon Jun 24 2013 jsuchome@suse.cz
- show checkbox for adding online repositories during installation
- add e17 desktop to the list of desktops (fate#315061)
* Mon May 27 2013 locilka@suse.com
- Using unique IDs while calling rpmcopy_secondstage to prevent
  from disabling this step in AutoYaST or Upgrade while it should
  be disabled only in Installation (bnc#813072).
* Thu May 16 2013 coolo@suse.com
- change urls to 13.1
* Fri Mar 29 2013 jsuchome@suse.cz
- Guide user to drivers.suse.com if HW was not found
  (fate#312875, bnc#805251)
* Fri Feb  1 2013 coolo@suse.com
- use 12.3 community repos
* Tue Oct 23 2012 jsuchome@suse.cz
- removed inst_suseconfig step (global SuSEconfig removal)
* Tue Oct  2 2012 bwiedemann@suse.com
- update to 12.3 repos
* Thu Jun 28 2012 lnussel@suse.de
- add non-oss update repo
* Mon Jun 25 2012 coolo@suse.com
- use 12.2 repos for "community"
* Thu Jun 14 2012 mlin@suse.com
- Desktop 'kde-plasma' replaced with 'kde4' (bnc#763142)
* Mon Feb 13 2012 coolo@suse.com
- update to 12.2 repos (bnc#746668)
* Tue Dec  6 2011 coolo@suse.com
- YaST is not a license
* Thu Oct 27 2011 jsuchome@suse.cz
- save ecdsa keys as well (bnc#726468)
* Mon Oct 17 2011 coolo@suse.com
- require branding-openSUSE for yast
* Mon Sep 26 2011 jsuchome@suse.cz
- also ensure lightdm package is installed
* Mon Sep 26 2011 jsuchome@suse.cz
- use lightdm as default DM for Xfce
* Thu Sep  1 2011 coolo@suse.com
- install minimal_base-conflicts for minimal text
* Tue Jun  7 2011 coolo@novell.com
- use 12.1 community repos url
* Mon May 30 2011 coolo@novell.com
- update control.xml to get 12.1 repos
* Fri May 20 2011 lnussel@suse.de
- change write_hostname_to_hosts to false (fate#308824)
* Mon Feb 28 2011 coolo@novell.com
- use 114 community repos
* Tue Feb  8 2011 locilka@suse.cz
- Adapted openSUSE control file to the current naming schema of
  desktops (BNC #667408)
* Thu Feb  3 2011 jsrain@suse.cz
- fixed consistency issues in live installer proposal
* Fri Jan 28 2011 coolo@novell.com
- change "minimal text" from base to minimal_base
* Mon Jan 24 2011 jsrain@suse.cz
- adaptations for unattended migration (fate#310481)
* Mon Jan 17 2011 coolo@novell.com
- make reduced package list really minimal (once again, bnc#577791)
* Mon Jan 17 2011 coolo@novell.com
- add debug update repo too (bnc#633628)
* Fri Jan  7 2011 jsrain@suse.cz
- update XFCE desktop definition
* Tue Aug 31 2010 coolo@novell.com
- update 11.4 urls
* Wed Jun 23 2010 coolo@novell.com
- use 11.3 url also for community repos (bnc#616355)
* Tue Feb  9 2010 locilka@suse.cz
- Steps 'user' and 'auth' enabled again in Live mode (BNC #547931).
* Tue Feb  2 2010 locilka@suse.cz
- Added LXDE desktop (FATE #307729).
* Thu Jan 21 2010 coolo@novell.com
- replace 11.2 urls by 11.3
* Wed Jan 20 2010 coolo@novell.com
- update to SVN to get new kdm package name and some storage fixes
* Tue Nov 24 2009 kmachalkova@suse.cz
- New variable in globals: run_init_scripts_in_parallel, to set
  /etc/sysconfig/boot:RUN_PARALLEL (FaTE#307555)
* Fri Nov  6 2009 coolo@novell.com
- fix the priority of the update repo
* Mon Sep 14 2009 coolo@novell.com
- update control.xml from svn (more text massage and
  correct community repos)
* Mon Sep  7 2009 kmachalkova@suse.cz
- New texts for DE selection dialog (FaTE #306967)
* Fri Sep  4 2009 kmachalkova@suse.cz
- Introducing unique IDs to unambiguously identify AC steps and
  sub-proposals
- xfce login manager is back to xdm (bnc#481468)
* Wed Aug 26 2009 kmachalkova@suse.cz
- KDE is now the default desktop environment (FaTE #306967)
* Fri Aug 14 2009 kmachalkova@suse.cz
- Simple network (firewall) configuration in 1st stage (FaTE #303859)
* Mon Aug 10 2009 locilka@suse.cz
- added calling bootloader client bootloader_preupdate to control
  file to fix multiple grub entries (bnc #414490, bnc #477778).
- disabled x11 proposal (bnc #441404).
* Wed Jul 22 2009 coolo@novell.com
- kdm package was renamed
* Tue May 26 2009 coolo@suse.de
- FATE: #303893, #305588: Default to enabled kdump
- update the descriptions of KDE and GNOME
* Fri Apr 10 2009 locilka@suse.cz
- KDE 3.x dropped from openSUSE control file (bnc #493547).
* Thu Apr  9 2009 coolo@suse.de
- update descriptions for KDE and GNOME
* Mon Mar 30 2009 locilka@suse.cz
- Added new globals->ac_redraw_and_ignore control file item that
  ignores if AC UI is missing and just redraws it (bnc #487565).
* Wed Mar 18 2009 locilka@suse.cz
- Unified inst_mode handling, especially correct handling of
  Automatic Configuration together with switching to Update mode
  (originally reported as bnc #469273).
- Repair workflow unified with the rest of installation.
* Sun Mar  1 2009 coolo@suse.de
- update to 11.2
* Mon Feb  2 2009 locilka@suse.cz
- Removing all do_resize calls, client has been removed
  (bnc #471295).
- Adding more comments.
- GDM as a default login manager for Xfce.
* Mon Jan 26 2009 coolo@suse.de
- verify the fix works and leave out the 11.1
* Wed Jan 21 2009 coolo@suse.de
- no longer noarch, we need special case for ppc
* Fri Dec  5 2008 locilka@suse.cz
- Using new control file validation - control.rng (bnc #455994)
* Wed Dec  3 2008 locilka@suse.cz
- inst_extrasources moved before inst_ask_online_update to register
  the online update repository before checking for patches
  (bnc #450229).
* Sat Nov 29 2008 coolo@suse.de
- rewrite the urls on ppc (bnc#449200)
* Wed Nov 26 2008 coolo@suse.de
- we moved the debug repo to /debug and the update repo doesn't need
  to be named like in NCC, so we can use the same pattern as the
  other repos
* Wed Nov 19 2008 coolo@suse.de
- update list of dropped packages
* Mon Oct 27 2008 locilka@suse.cz
- Desktop 'startkde4' replaced with 'startkde' (bnc #438212).
- Calling inst_prepareprogress also during Upgrade, all control
  files changed (bnc #438848).
- Removing label for user_non_interactive (bnc #401319).
- Disabling users and auth in LiveCD second stage (bnc #435965).
* Mon Oct 13 2008 locilka@suse.cz
- Fixed text in openSUSE control file (bnc #432911).
* Wed Oct  8 2008 locilka@suse.cz
- Added cont_suseconfig to the list of clients called during second
  stage even if AC is turned on (bnc #428190).
- Added globals->default_ntp_setup=true that makes NTP to propose
  a default ntp server.
* Mon Sep 29 2008 locilka@suse.cz
- Adding inst_lilo_convert to the update workflow (bnc #430579).
* Mon Sep 29 2008 locilka@suse.cz
- Updated KDE description (bnc #427692)
* Mon Sep 22 2008 locilka@suse.cz
- KDE 3.5 moved to 'Others', removed KDE 3.5 description text.
- GNOME 2.22 changed to 2.24.
* Fri Sep 12 2008 locilka@suse.cz
- Not calling inst_suse_register anymore (FATE #303458).
* Wed Sep 10 2008 locilka@suse.cz
- <execute> tag must mention the exact name of a script to call
  (bnc #425198).
* Wed Sep 10 2008 locilka@suse.cz
- Desktop selection dialog definitions have been moved to control
  file (bnc #424678).
* Mon Sep  8 2008 locilka@suse.cz
- Fixed partitioning sizes (G -> GB) (aschnell)
- Added more modules to the 'clone' section (ug).
* Wed Sep  3 2008 locilka@suse.cz
- Using new <execute/> tag in control file to explicitly define
  a client to be called instead of guessing it from <name/> tag
  (bnc #401319).
- Updated control files to call inst_prepareprogress to
  "Provide consistent progress during installation" (FATE #303860).
- All 'inst_proposal' calls changed to use the new 'execute'
  feature to have unique 'name's (needed for merging add-on control
  files).
* Fri Aug 15 2008 locilka@suse.cz
- Added new globals->write_hostname_to_hosts control file option
  to configure the default for 127.0.0.2 issue (FATE #303875).
* Fri Aug 15 2008 coolo@suse.de
- switch to 11.1 repos
* Tue Aug 12 2008 locilka@suse.cz
- Configuration of files that will be imported from previous
  installation has been moved to control file (FATE #305019).
- Explicitely not-enabling runlevel 4 (FATE #303798).
* Tue Jul 15 2008 locilka@suse.cz
- Automatic Configuration setup moved to control file to make
  redetection of hardware possible for firstboot too (FATE #303939)
- Added new feature globals->base_product_license_directory to
  define where to store the base-product licenses (FATE #304865)
* Mon Jun  2 2008 coolo@suse.de
- switching to 11.0 repos (bnc#395316)
* Wed May 28 2008 coolo@suse.de
- the updates alias has to match what NCC says
* Tue May 27 2008 coolo@suse.de
- more packages to drop
* Mon May 19 2008 locilka@suse.cz
- Adding FACTORY repositories with priority 120, update source with
  priority 20 (bnc #392039).
* Fri May  9 2008 coolo@suse.de
- create users during live cd installation
- update list of dropped packages
* Wed May  7 2008 locilka@suse.cz
- Added software->dropped_packages into the control file to replace
  'delete old packages' (bnc #300540).
* Tue May  6 2008 jsrain@suse.cz
- use separate definition of firstboot 2nd stage workflow,
  add clean up at the end (bnc #385829)
* Mon Apr 28 2008 locilka@suse.cz
- Optional and extra URLs moved to control file as well as default
  update repository (bnc #381360).
* Mon Apr 28 2008 jsrain@suse.cz
- Added runlevel to live installation proposal (bnc #381426)
* Fri Apr 25 2008 locilka@suse.cz
- New desktop selection dialog (bnc #379157).
* Tue Apr 22 2008 locilka@suse.cz
- Client inst_prepare_image moved to installation proposal make
  disabling 'installation from images' easy (bnc #381234).
* Wed Apr 16 2008 locilka@suse.cz
- Running runlevel proposal after software proposal (bnc #380141).
* Wed Apr  9 2008 locilka@suse.cz
- Adjusted control file to sort installation overview via
  presentation_order and propose it via the real appearance.
* Mon Apr  7 2008 locilka@suse.cz
- Added new control file entry kexec_reboot that defines whether
  kexec should be used instead of reboot at the end of the first
  stage installation (FATE #303395).
* Fri Apr  4 2008 jsrain@suse.cz
- do inst_kickoff after deploying images in order not to rewrite
  any files with files from the images
- updated live installation workflow
* Thu Apr  3 2008 locilka@suse.cz
- Added possibility to show or hide community repositories and
  add-on products during installation, including default values
  of check-boxes.
* Tue Apr  1 2008 jsrain@suse.cz
- added live installation workflow to default control file.
* Tue Apr  1 2008 locilka@suse.cz
- Automatic configuration can be newly defined by control file. Two
  new variables have been added enable_autoconfiguration and
  autoconfiguration_default.
* Fri Mar 28 2008 locilka@suse.cz
- Automatic configuration has been moved from the end of the first
  stage to the second stage. It's non-interactive (FATE #303396).
* Wed Mar 26 2008 locilka@suse.cz
- Added new entry to control file root_password_as_first_user to
  make it configurable (bnc #359115 comment #14).
- Control file modified to call installation-from-images clients.
* Mon Mar 17 2008 locilka@suse.cz
- The whole second stage in now disabled for mode update
  (FATE #303396).
* Sat Mar 15 2008 locilka@suse.cz
- Calling new script inst_rpmcopy_secondstage in second stage
  instead of inst_rpmcopy because of step-name conflict disabled
  by DisabledModules during automatic configuration (fate #303396).
* Mon Mar 10 2008 locilka@suse.cz
- country_simple is for keyboard and language, not for timezone
- added 1st stage step for root password dialog (fate#302980)
  (both by jsuchome)
* Wed Mar  5 2008 locilka@suse.cz
- Using client country_simple instead of timezone and language in
  the installation overview (FATE #302980).
- Using new users client in that overview too (FATE #302980).
* Fri Feb 22 2008 locilka@suse.cz
- "iscsi-client" added into modules to clone (bnc #363229 c#1).
* Mon Feb  4 2008 locilka@suse.cz
- Tabs have been removed from installation proposal.
* Thu Jan 31 2008 locilka@suse.cz
- Fixed patch for CD version.
* Wed Jan 30 2008 fehr@suse.de
- Added disk proposal to after the software/desktop selection.
* Wed Jan 30 2008 locilka@suse.cz
- Added inst_user_first.ycp call to the control file right before
  the installation proposal.
* Mon Jan 14 2008 locilka@suse.cz
- Added new Language/Keyboard/License dialog (FATE #302957).
* Thu Jan 10 2008 locilka@suse.cz
- Online Repositories hidden by a show_online_repositories=false
  option (supported since yast2-installation-2.16.9).
* Mon Jan  7 2008 coolo@suse.de
- don't use 10.3 repos for factory (#346703)
* Wed Dec 19 2007 coolo@suse.de
- fix the patch for CD
* Tue Dec 18 2007 locilka@suse.cz
- Using inst_software_selection instead of inst_desktop
* Mon Dec 17 2007 locilka@suse.cz
- Script inst_system_analysis has been split into inst_mode and
  inst_system_analysis for a simpler maintainability.
* Thu Dec 13 2007 coolo@suse.de
- reenable language selection for the CDs again
* Thu Dec 13 2007 coolo@suse.de
- disable checkmedia, it will be on the CD boot menu only
* Mon Sep 24 2007 locilka@suse.cz
- Added new option online_repos_preselected: true for CD, false
  for the other media (#327791).
* Fri Sep  7 2007 coolo@suse.de
- Changed default delete_old_packages back to 'true' after finding
  and fixing all remaining issues with 'false'
* Wed Sep  5 2007 jsrain@suse.cz
- removed inst_fam (#307378)
* Fri Aug 10 2007 locilka@suse.cz
- Using "Online Repositories" for Internet/Web-based/Additional/...
  repositories downloaded from web during the first stage
  installation (#296407).
* Thu Aug  9 2007 locilka@suse.cz
- Re-enabled language proposals (#297985).
* Mon Aug  6 2007 locilka@suse.cz
- Fixed XML syntax.
* Mon Aug  6 2007 locilka@suse.cz
- Disabled back some buttons in oneCD installation.
- Renamed Language to License Agreement where no Language for oneCD
  installation.
* Wed Aug  1 2007 locilka@suse.cz
- Changed remote repositories link to finally point to
  http://download.opensuse.org/...
* Mon Jul 30 2007 locilka@suse.cz
- Upgrade process now also offers to use repositories used on the
  target system (FATE #301785).
* Wed Jul 25 2007 locilka@suse.cz
- Unified wizard step names with dialogs, removed Clean Up step
  part of the Online Update is now Registration (#293095).
* Fri Jul 20 2007 locilka@suse.cz
- Source package extended to build two different RPMS
  skelcd-control-openSUSE and skelcd-control-openSUSE-CD.
- Added control-cd.xml.diff patch as a difference between
  skelcd-control-openSUSE and skelcd-control-openSUSE-CD.
- Modified URL for additional repositories.
* Thu Jul 12 2007 locilka@suse.cz
- Changed link to external repositories that support the new
  One Click Install Standard XML.
* Wed Jul 11 2007 locilka@suse.cz
- Changed default delete_old_packages to 'false'.
* Wed Jul  4 2007 locilka@suse.cz
- Save /root content from installation system to the just installed
  system (FATE #301937).
- Added links to list of servers providing lists of external
  repositories (FATE #300898).
- Added dialog for handling the external repositories.
- From now it is possible to go back even when installation type
  has been selected.
* Wed May 30 2007 jsrain@suse.cz
- removed inst_netsetup
* Tue May 15 2007 locilka@suse.cz
- Changed control file in partitioning/evms_config section from
  'true' to 'false' (#274702).
* Thu May 10 2007 locilka@suse.cz
- openSUSE control file clean-up: The default value for enable_next
  and enable_back is 'yes'. Only few steps do not allow to go back
  (#270893).
* Wed Apr 18 2007 locilka@suse.cz
- Root password dialog has been moved to be the first dialog of the
  second stage installation workflow (FATE #301924).
- "Root Password" step is now called "root Password" (#249706).
- Created new 'Check Installation' entry to the 'Configuration'
  part of the workflow. This section contains setting up network
  if needed, initializing target if needed, and installing
  remaining software (needed by FATE #301924).
* Fri Apr 13 2007 locilka@suse.cz
- Replacing networkmanager_proposal with general_proposal (network)
  that includes also IPv6 settings (#263337, #260261).
* Wed Apr  4 2007 locilka@suse.cz
- Removed IPv6 proposal from installation control file. IPv6
  proposal has been merged into Network Mode proposal (#260261).
* Thu Jan 18 2007 locilka@suse.cz
- Changed option <clone_module> "lan" to "networking" (#235457).
* Fri Jan 12 2007 locilka@suse.cz
- control file variable for monthly suse_register run (F#301822)
  (change made by jdsn)
* Mon Dec  4 2006 locilka@suse.cz
- Enabling EVMS again (openSUSE 10.3)
- Adding root_password_ca_check item into the globals of control
  file set to true for SLES and false otherwise (FATE #300438).
* Wed Nov 29 2006 locilka@suse.cz
- Disabling EVMS (#224462).
* Tue Nov 14 2006 locilka@suse.cz
- limit_try_home: 5 GB -> 7 GB (#219878)
- root_base_size: 3 GB -> 5 GB (#219878)
* Tue Nov 14 2006 mzugec@suse.cz
- Providing an easier switch to disable IPv6 by a new ipv6 client
  in the network proposal (FATE #300604).
* Tue Oct 24 2006 locilka@suse.cz
- Package skelcd-control-SUSELinux-Prof renamed to
  skelcd-control-openSUSE.
* Mon Oct 23 2006 locilka@suse.cz
- Adding add-on client to list of clients that are enabled for
  AutoYaST cloning (bugzilla #198927).
* Mon Oct 16 2006 fehr@suse.de
- added new configurable values for LVM/EVMS based proposals
  (feature 300169)
- change evms_config to true
* Mon Oct 16 2006 locilka@suse.cz
- Root Password dialog moved before Hostname and Domain Name
  (#208032).
- new inst_extrasources.ycp client - add extra installation sources
  during installation (in 2nd stage, after online update)
  (fate #100168, #300910) (lslezak)
* Thu Aug 10 2006 jsrain@suse.cz
- fixed congratulation text for openSUSE (#198252)
* Thu Jul 27 2006 jsrain@suse.cz
- adjusted to use country_simple proposal item
* Tue Jul 25 2006 jsrain@suse.cz
- added keyboard layout to simple proposal tab (#161791)
* Fri May  5 2006 jsrain@suse.cz
- added congratulate text to the control file (#170881)
* Thu Apr 20 2006 mvidner@suse.cz
- added globals/disable_register_w3m (#167255, jdsn)
* Fri Apr 14 2006 jsrain@suse.cz
- removed update system selection from update proposal (#165832)
* Thu Apr 13 2006 jsrain@suse.cz
- changed control files according to (#165509
* Wed Apr 12 2006 mvidner@suse.cz
- Control files updated for manual online update run (#165503).
- Add installation sources for online update (#163192).
* Tue Apr  4 2006 jsrain@suse.cz
- removed register section
* Wed Mar 29 2006 mvidner@suse.cz
- Added register/display_register_forcereg (jdsn).
* Tue Mar 28 2006 jsrain@suse.cz
- added autoyast part of suse_register
* Thu Mar 23 2006 mvidner@suse.cz
- Added register/enable_register_{hwdata,optional}.
* Fri Mar 17 2006 jsrain@suse.cz
- increase maximal size of root fs to 20 Gig (#158608)
* Tue Mar 14 2006 jsrain@suse.cz
- changed title for registration in installation workflow
* Thu Mar  9 2006 mvidner@suse.cz
- added network/startmode=ifplugd (#156388).
* Tue Mar  7 2006 jsrain@suse.cz
- adapted for online update (jdsn)
* Wed Mar  1 2006 jsrain@suse.cz
- added suse_resgister to installation workflow
* Fri Feb 17 2006 jsrain@suse.cz
- integrated add-on products installation
* Tue Feb  7 2006 mvidner@suse.cz
- Configure the hostname in the main installation workflow (#142758).
- Merged proofread texts.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 jsrain@suse.cz
- Added networkmanager_proposal to the network proposal
* Thu Jan  5 2006 jsrain@suse.cz
- integrated iSCSI installation
* Fri Dec 16 2005 jsrain@suse.cz
- added list of modules to offer to clone after the end of
  installation
* Fri Dec  2 2005 jsrain@suse.cz
- added control file variables network_manager_is_default,
  force_static_ip (mvidner)
* Mon Nov 28 2005 jsrain@suse.cz
- do not preselect any desktop (#132491)
* Tue Nov 22 2005 jsrain@suse.cz
- added default desktop to control file
* Tue Nov  1 2005 jsrain@suse.cz
- adapted to rename inst_desktop_new.ycp -> inst_desktop.ycp
* Mon Sep  5 2005 jsrain@suse.cz
- save all configured hardware at the end of installation (#104676)
* Wed Aug 24 2005 jsrain@suse.cz
- do not call inst_x11 during autoinstallation (#112709)
* Mon Aug 22 2005 jsrain@suse.de
- specify additional parameters to inst_timezone (#104868)
* Thu Aug 18 2005 jsrain@suse.cz
- don't set FAM daemon on by default (#105153)
- use redesigned dialog for desktop selection (#104643)
* Fri Aug 12 2005 jsrain@suse.cz
- added proposal for VM settings (#102583)
* Thu Aug  4 2005 jsrain@suse.cz
- changed the label "Device Configuration" step to
  "Hardware Configuration" (#100642)
* Wed Jul 27 2005 jsrain@suse.cz
- updated update workflow (#98834)
* Mon Jul 18 2005 jsrain@suse.de
- removed duplicated license agreement
- removed installation/update selection from proposals
* Fri Jul 15 2005 jsrain@suse.cz
- added new installation steps and simple/expert proposal
* Thu Feb 17 2005 nashif@suse.de
- Enable options for skipping language dialog (#37679)
* Mon Feb 14 2005 nashif@suse.de
- Added missing labels
* Wed Feb  9 2005 nashif@suse.de
- #50369: kernel parameter set in global variable
- #50623: Set enable_skip to yes
* Tue Feb  1 2005 nashif@suse.de
- Added checkmedia step
* Thu Jan 27 2005 nashif@suse.de
- Removed old client arguments
* Tue Jan 25 2005 nashif@suse.de
- Fixed arguments of workflow clients. use plain yes/no instead of
  false/true
* Tue Jan 25 2005 nashif@suse.de
- Enahncements for new workflow interface
* Thu Jan  6 2005 nashif@suse.de
- Fixed autoyast modes
- Fixed system update proposal (#49608)
* Mon Sep 27 2004 nashif@suse.de
- Remove netsetup `dn from workflow (#45317)
* Wed Sep 15 2004 visnov@suse.de
- Added enable_firewall and enable_ssh values
- Set enable_ssh to false
* Mon Sep 13 2004 nashif@suse.de
- adjust fam on professional if running GNOME
* Mon Sep 13 2004 nashif@suse.de
- Added ui_mode simple (#44505)
* Thu Sep  2 2004 nashif@suse.de
- Move firewall up in the network proposal
* Mon Aug 30 2004 nashif@suse.de
- Added x11 as a step in autoinst mode
- shutdown installation netwrok before system config in autoyast
* Mon Aug 23 2004 nashif@suse.de
- Added bluetooth proposal
* Wed Aug 11 2004 nashif@suse.de
- Added firewall to network proposal (#43718)
* Tue Aug 10 2004 nashif@suse.de
- Fixed proposal arguments
* Mon Aug  9 2004 nashif@suse.de
- Added Proposal Labels
- Removed comments
- Added new retranslation keyword to initiate retrans on certain
  dialogs
* Fri Apr 16 2004 ro@suse.de
- gain control over version number
* Thu Apr  1 2004 nashif@suse.de
- Removed 'Network' label (#37546)
* Thu Apr  1 2004 nashif@suse.de
- Added missing workflow step to shut network down in
  second phase of installation (#37546, #37763)
* Wed Mar 31 2004 nashif@suse.de
- removed network proposal from update workflow
* Wed Mar 31 2004 nashif@suse.de
- show warning about suboptimal distribution
* Thu Mar 25 2004 nashif@suse.de
- Initial release
